@@ -15,23 +15,29 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-icons.h,v 1.1 2003/09/17 11:55:47 makeinu Exp $
+ *  $Id: kz-icons.h,v 1.5 2003/11/10 19:06:06 makeinu Exp $
  */
 
 #ifndef KZ_ICONS_H
 #define KZ_ICONS_H
 
 #include <glib.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gtk/gtkenums.h>
 
 G_BEGIN_DECLS
 
-#define KZ_STOCK_GOOGLE "kz-google"
-#define KZ_STOCK_GREEN  "kz-green"
-#define KZ_STOCK_RED    "kz-red"
+#define KZ_STOCK_GOOGLE       "kz-google"
+#define KZ_STOCK_GREEN        "kz-green"
+#define KZ_STOCK_RED          "kz-red"
+#define KZ_STOCK_FOLDER       "kz-folder"
+#define KZ_STOCK_FOLDER_OPEN  "kz-folder-open"
+#define KZ_STOCK_SEPARATOR    "kz-separator"
 
 extern GtkIconSize KZ_ICON_SIZE_BOOKMARK_MENU;
 
+extern GdkPixbuf *kz_icon;
+
 void kz_icons_init (void);
 
 G_END_DECLS
