@@ -26,7 +26,6 @@
 
 #include "egg-action-group.h"
 #include "egg-menu-merge.h"
-#include "kz-mozembed.h"
 #include "kz-gesture.h"
 #include "kz-embed-event.h"
 
@@ -39,31 +38,6 @@ G_BEGIN_DECLS
 #define KZ_IS_WINDOW_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), KZ_TYPE_WINDOW))
 #define KZ_WINDOW_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), KZ_TYPE_WINDOW, KzWindowClass))
 
-#define KZ_WINDOW_NTH_PAGE(kz, n) \
-	(KZ_IS_WINDOW(kz) ? gtk_notebook_get_nth_page(GTK_NOTEBOOK(KZ_WINDOW(kz)->notebook),n) : NULL)
-#define KZ_WINDOW_CURRENT_PAGE(kz) \
-	(KZ_IS_WINDOW(kz) ? KZ_WINDOW_NTH_PAGE(kz, gtk_notebook_get_current_page(GTK_NOTEBOOK(kz->notebook))) : NULL)
-
-#define KZ_WINDOW_SET_SENSITIVE(kz, action_name, sensitive)		       \
-{									       \
-	if (KZ_IS_WINDOW(kz) && EGG_IS_ACTION_GROUP(kz->action_group)) {       \
-		EggAction *action;					       \
-		action = egg_action_group_get_action(kz->action_group,	       \
-						     action_name);	       \
-		if (action) egg_action_set_sensitive(action, sensitive);       \
-	}								       \
-}
-
-#define KZ_WINDOW_SET_VISIBLE(kz, action_name, visible)			       \
-{									       \
-	if (KZ_IS_WINDOW(kz) && EGG_IS_ACTION_GROUP(kz->action_group)) {       \
-		EggAction *action;					       \
-		action = egg_action_group_get_action(kz->action_group, 	       \
-						     action_name);	       \
-		if (action) egg_action_set_visible(action, visible);	       \
-	}								       \
-}
-
 typedef struct _KzWindow	KzWindow;
 typedef struct _KzWindowClass	KzWindowClass;
 typedef struct _KzWindowPriv	KzWindowPriv;
@@ -75,7 +49,7 @@ struct _KzWindow
 	GtkWidget  *top_vbox;
 
 	/* top of the window */
-	GtkWidget  *url_entry;
+	GtkWidget  *bookmarkbar;
 
 	/* middle of the window */
 	GtkWidget  *pane;
@@ -83,20 +57,18 @@ struct _KzWindow
 	GtkWidget  *notebook;
 
 	/* bottom of the window */
-	GtkWidget  *progress_area_hbox;
-	GtkWidget  *progressbar;
-	GtkWidget  *status_align;
-	GtkWidget  *statusbar;
-	GtkWidget  *find_area_hbox;
+	GtkWidget  *statusbar_area;
+
 	GtkWidget  *find_area;
-	GtkWidget  *kztoolbar;
+	GtkWidget  *find_direction;
+	GtkWidget  *statusbar;
+	GtkWidget  *dlbox;
 
 	/* other objects */
-	GtkAccelGroup  *accel_group;
-	EggActionGroup *action_group;
-	EggActionGroup *popup_action_group;
+	EggActionGroup *actions;
+	EggActionGroup *popup_actions;
+	EggActionGroup *tabpop_actions;
 	EggMenuMerge   *menu_merge;
-	KzGestureItems *gesture_items;
 
 	KzWindowPriv *priv;
 };
@@ -106,45 +78,75 @@ struct _KzWindowClass
 	GtkWindowClass parent_class;
 
 	/* -- signals -- */
-	void (*append_tab) (KzWindow  *kz,
-			    GtkWidget *widget,
-			    GtkWidget *parent);
-	void (*remove_tab) (KzWindow  *kz,
-			    GtkWidget *widget);
+	void (*append_tab)  (KzWindow  *kz,
+			     GtkWidget *widget,
+			     GtkWidget *parent);
+	void (*remove_tab)  (KzWindow  *kz,
+			     GtkWidget *widget);
+	void (*reorder_tab) (KzWindow  *kz,
+			     GtkWidget *widget,
+			     gint       pos);
 };
 
 GtkType	          kz_window_get_type                 (void);
 GList            *kz_window_get_window_list          (void);
 GtkWidget        *kz_window_new                      (const gchar *url);
-GtkWidget        *kz_window_get_from_tab             (GtkWidget *tab_widget);
-GtkWidget        *kz_window_open_new_tab             (KzWindow *kz,
+GtkWidget        *kz_window_get_from_tab             (GtkWidget   *tab_widget);
+GtkWidget        *kz_window_open_new_tab             (KzWindow    *kz,
 						      const gchar *url);
-GtkWidget        *kz_window_open_new_tab_with_parent (KzWindow *kz,
+GtkWidget        *kz_window_open_new_tab_with_parent (KzWindow    *kz,
 						      const gchar *url,
-						      GtkWidget *parent);
-void              kz_window_close_tab                (KzWindow *kz,
-						      GtkWidget *widget);
-void              kz_window_close_tab_idle           (KzWindow *kz,
-						      GtkWidget *widget);
-void              kz_window_move_tab                 (KzWindow *kz,
-						      GtkWidget *widget);
-void              kz_window_load_url                 (KzWindow *kz,
+						      GtkWidget   *parent);
+void              kz_window_close_tab                (KzWindow    *kz,
+						      GtkWidget   *widget);
+void              kz_window_close_all_tab            (KzWindow    *kz);
+void              kz_window_reorder_tab              (KzWindow    *kz,
+						      GtkWidget   *widget,
+						      gint         position);
+void              kz_window_move_tab                 (KzWindow    *kz,
+						      GtkWidget   *widget);
+void              kz_window_load_url                 (KzWindow    *kz,
 						      const gchar *url);
-void              kz_window_load_home                (KzWindow *kz);
-void              kz_window_set_visibility           (KzWindow *kz,
-						      gboolean visibility);
-const gchar      *kz_window_get_title                (KzWindow *kz);
-const gchar      *kz_window_get_uri                  (KzWindow *kz);
+void              kz_window_load_home                (KzWindow    *kz);
+void              kz_window_store_state              (KzWindow    *kz);
+void              kz_window_restore_state            (KzWindow    *kz);
+const gchar      *kz_window_get_title                (KzWindow    *kz);
+const gchar      *kz_window_get_uri                  (KzWindow    *kz);
 
-GtkWidget        *kz_window_get_tab_label            (KzWindow *kz,
-						      GtkWidget *widget);
+GtkWidget        *kz_window_get_tab_label            (KzWindow    *kz,
+						      GtkWidget   *widget);
 
-void              kz_window_update_nav_buttons       (KzWindow *kz,
-						      KzMozEmbed *current);
-GNode            *kz_window_get_tree                 (KzWindow *kz);
+GNode            *kz_window_get_tree                 (KzWindow    *kz);
 
 const KzEmbedEventMouse *
-		  kz_window_get_mouse_event_info     (KzWindow *kz);
+		  kz_window_get_mouse_event_info     (KzWindow    *kz);
+
+
+
+#define KZ_WINDOW_NTH_PAGE(kz, n) \
+	(KZ_IS_WINDOW(kz) ? gtk_notebook_get_nth_page(GTK_NOTEBOOK(KZ_WINDOW(kz)->notebook),n) : NULL)
+#define KZ_WINDOW_CURRENT_PAGE(kz) \
+	(KZ_IS_WINDOW(kz) ? KZ_WINDOW_NTH_PAGE(kz, gtk_notebook_get_current_page(GTK_NOTEBOOK(kz->notebook))) : NULL)
+
+#define KZ_WINDOW_SET_SENSITIVE(kz, action_name, sensitive)		       \
+{									       \
+	if (KZ_IS_WINDOW(kz) && EGG_IS_ACTION_GROUP(kz->actions)) {	       \
+		EggAction *action;					       \
+		action = egg_action_group_get_action(kz->actions,	       \
+						     action_name);	       \
+		if (action) egg_action_set_sensitive(action, sensitive);       \
+	}								       \
+}
+
+#define KZ_WINDOW_SET_VISIBLE(kz, action_name, visible)			       \
+{									       \
+	if (KZ_IS_WINDOW(kz) && EGG_IS_ACTION_GROUP(kz->actions)) {	       \
+		EggAction *action;					       \
+		action = egg_action_group_get_action(kz->actions, 	       \
+						     action_name);	       \
+		if (action) egg_action_set_visible(action, visible);	       \
+	}								       \
+}
 
 G_END_DECLS
 
