@@ -28,13 +28,109 @@
 #include <gtk/gtk.h>
 
 #include "kazehakase.h"
+#include "kz-icons.h"
 #include "kz-window.h"
+#include "kz-xbel.h"
 #include "intl.h"
 #include "locale.h"
 #include "mozilla.h"
 
 
-Profile *kz_global_profile = NULL;
+KzProfile   *kz_global_profile = NULL;
+KzProfile   *kz_session        = NULL;
+KzProfile   *kz_proxy          = NULL;
+KzBookmark  *kz_bookmark       = NULL;
+KzBookmark  *kz_home           = NULL;
+
+
+
+/******************************************************************************
+ *                                                                            *
+ *                                 UI Level                                   *
+ *                                                                            *
+ ******************************************************************************/
+KzUILevel
+kz_ui_level (void)
+{
+	KzUILevel val;
+	gchar level[16];
+
+	g_return_val_if_fail(KZ_IS_PROFILE(kz_global_profile),
+			     KZ_UI_LEVEL_BEGINNER);
+
+	level[0] = '\0';
+	kz_profile_get_value(kz_global_profile,
+			     "Global", "ui_level",
+			     level, sizeof(level),
+			     KZ_PROFILE_VALUE_TYPE_STRING);
+
+	val = kz_ui_level_from_str(level);
+	if (!val)
+		return KZ_UI_LEVEL_BEGINNER;
+
+	return val;
+}
+
+
+KzUILevel
+kz_ui_level_from_str (const gchar *level)
+{
+	if (!level || !*level)
+		return KZ_UI_LEVEL_INVALID;
+
+	if (!strcmp(level, "custom"))
+		return KZ_UI_LEVEL_CUSTOM;
+	else if (!strcmp(level, "expert"))
+		return KZ_UI_LEVEL_EXPERT;
+	else if (!strcmp(level, "medium"))
+		return KZ_UI_LEVEL_MEDIUM;
+	else if (!strcmp(level, "beginner"))
+		return KZ_UI_LEVEL_BEGINNER;
+
+	return KZ_UI_LEVEL_INVALID;
+}
+
+
+const gchar *
+kz_ui_level_to_str (KzUILevel level)
+{
+	switch (level)
+	{
+	case KZ_UI_LEVEL_CUSTOM:
+		return "custom";
+	case KZ_UI_LEVEL_EXPERT:
+		return "expert";
+	case KZ_UI_LEVEL_MEDIUM:
+		return "medium";
+	case KZ_UI_LEVEL_BEGINNER:
+		return "beginner";
+	default:
+		break;
+	}
+
+	return NULL;
+}
+
+
+const gchar *
+kz_ui_level_to_suffix (KzUILevel level)
+{
+	switch (level)
+	{
+	case KZ_UI_LEVEL_CUSTOM:
+		return "\0";
+	case KZ_UI_LEVEL_EXPERT:
+		return "Ex";
+	case KZ_UI_LEVEL_MEDIUM:
+		return "Med";
+	case KZ_UI_LEVEL_BEGINNER:
+		return "Beg";
+	default:
+		break;
+	}
+
+	return NULL;
+}
 
 
 /******************************************************************************
@@ -187,67 +283,149 @@ check_kazehakase_process (int argc, char *argv[])
  *                                  Main                                      *
  *                                                                            *
  ******************************************************************************/
+static void
+open_app_info (void)
+{
+	gchar *sysconf_file, *conf_file, *session_file;
+	gchar *bookmark_file;
+	gchar *accel_prefs_file;
+	gchar *proxy_file, *sysproxy_file;
+
+	/* load prefs */
+	sysconf_file = g_strdup(KZ_SYSCONFDIR "/kzrc");
+	conf_file = g_strconcat(g_get_home_dir(), "/.kazehakase/kzrc", NULL);
+	kz_global_profile = kz_profile_open(conf_file, sysconf_file);
+
+	/* load sessions */
+	session_file = g_strconcat(g_get_home_dir(),
+				   "/.kazehakase/sessionrc",
+				   NULL);
+	kz_session = kz_profile_open(session_file, NULL);
+
+	/* load bookmarks */
+	bookmark_file = g_strconcat(g_get_home_dir(),
+				    "/.kazehakase/bookmarks.xml",
+				    NULL);
+	if (g_file_test(bookmark_file, G_FILE_TEST_EXISTS))
+	{
+		kz_bookmark = kz_bookmark_file_new(bookmark_file, _("Bookmarks"),
+						   NULL);
+		kz_bookmark_load_start(kz_bookmark);
+	}
+	else
+		kz_bookmark = kz_bookmark_file_create_new(bookmark_file, _("Bookmarks"),
+							  "XBEL");
+
+	bookmark_file = g_strconcat(g_get_home_dir(),
+				    "/.kazehakase/home.xml",
+				    NULL);
+	if (g_file_test(bookmark_file, G_FILE_TEST_EXISTS))
+	{
+		kz_home = kz_bookmark_file_new(bookmark_file, _("Home & Lairs"),
+					       NULL);
+		kz_bookmark_load_start(kz_home);
+	}
+	else
+		kz_home = kz_bookmark_file_create_new(bookmark_file, _("Home & Lairs"),
+						      "XBEL");
+		
+	/* Load other prefs... */
+	accel_prefs_file = g_strconcat (g_get_home_dir(),
+					"/.kazehakase/keyaccelrc",
+					NULL);
+	gtk_accel_map_load (accel_prefs_file);
+
+	sysproxy_file = g_strdup(KZ_SYSCONFDIR "/proxyrc");
+	proxy_file = g_strconcat (g_get_home_dir(), "/.kazehakase/proxyrc", NULL);
+	kz_proxy = kz_profile_open(proxy_file, sysproxy_file);
+
+	kz_icons_init();
+	mozilla_init();
+
+	g_free(sysconf_file);
+	g_free(conf_file);
+	g_free(session_file);
+	g_free(bookmark_file);
+	g_free(accel_prefs_file);
+	g_free(sysproxy_file);
+	g_free(proxy_file);
+}
+
+
+static void
+close_app_info (void)
+{
+	gchar *accel_prefs_file;
+
+	accel_prefs_file = g_strconcat (g_get_home_dir(),
+					"/.kazehakase/keyaccelrc",
+					NULL);
+
+	gtk_accel_map_save(accel_prefs_file);
+	g_free(accel_prefs_file);
+
+	mozilla_exit();
+
+	kz_profile_close(kz_global_profile);
+	kz_profile_close(kz_session);
+	kz_profile_close(kz_proxy);
+
+	kz_bookmark_save(kz_home);
+	g_object_unref(G_OBJECT(kz_home));
+	kz_bookmark_save(kz_bookmark);
+	g_object_unref(G_OBJECT(kz_bookmark));
+
+	kz_global_profile = NULL;
+	kz_session        = NULL;
+	kz_proxy          = NULL;
+	kz_bookmark       = NULL;
+}
+
+
 int
 main (int argc, char *argv[])
 {
 	KzWindow *kz = NULL;
 	GtkWidget *dupl_check_server = NULL;
 	const gchar *url = NULL;
-	const gchar *sysconf_file, *conf_file;
 	gint i;
 
-	/*
-	 *  initialize
-	 */
+	/* initialize */
 	setlocale(LC_ALL, "");
 	bindtextdomain(PACKAGE, LOCALEDIR);
 	bind_textdomain_codeset(PACKAGE, "UTF-8");
 	textdomain(PACKAGE);
 
-	sysconf_file = SYSCONFDIR "/kzrc";
-	conf_file = g_strconcat(g_get_home_dir(), "/.kazehakase/kzrc", NULL);
-	kz_global_profile = profile_open(conf_file, sysconf_file);
-	/* FIXME!!: set default preference */
-
 	gtk_set_locale();
 	gtk_init(&argc, &argv);
-	mozilla_init();
 
-
-	/*
-	 *  find kazehakase process
-	 */
+	/* find kazehakase process */
 	dupl_check_server = check_kazehakase_process(argc, argv);
-	if (!dupl_check_server) return 0;   /* found kazehakase process */
+	if (!dupl_check_server)
+	{
+		/* FIXME! show message */
+		return 0;   /* found kazehakase process */
+	}
 
+	/* Load preference */
+	open_app_info();
 
-	/*
-	 *  create window
-	 */
+	/* create window */
 	if (argc > 1)
 		url = argv[1];
-
 	kz = KZ_WINDOW(kz_window_new(url));
-
 	for (i = 2; i < argc; i++)
 		kz_window_open_new_tab(kz, argv[i]);
+	gtk_widget_show(GTK_WIDGET(kz));
 
-	kz_window_set_visibility(kz, TRUE);
-
-
-	/*
-	 *  event loop
-	 */
+	/* event loop */
 	gtk_main();
 
-
-	/*
-	 *  exit
-	 */
+	/* exit */
 	gtk_widget_destroy(dupl_check_server);
 	dupl_check_server = NULL;
-	mozilla_exit();
-	profile_close(kz_global_profile);
+
+	close_app_info();
 
 	return 0;
 }
