@@ -27,8 +27,8 @@
 #include <xpcom/nsCOMPtr.h>
 #include <pref/nsIPrefService.h>
 #include <uconv/nsICharsetConverterManager.h>
-#ifndef MOZILLA_SNAPSHOT
-#include <uconv/nsICharsetConverterManager2.h>
+#if MOZILLA_SNAPSHOT < 10
+#	include <uconv/nsICharsetConverterManager2.h>
 #endif
 #include <xpcom/nsISupportsPrimitives.h>
 #include <gfx/nsIFontList.h>
@@ -36,6 +36,7 @@
 
 #include "kazehakase.h"
 #include "kz-profile.h"
+#include "kz-proxy-item.h"
 
 
 extern "C" gboolean
@@ -59,7 +60,7 @@ mozilla_prefs_init (void)
 
 
 static void
-set_user_agent (gchar *user_agent, gint size)
+build_user_agent (gchar *user_agent, gint size)
 {
 	struct utsname name;
 	gchar *system;
@@ -76,8 +77,7 @@ set_user_agent (gchar *user_agent, gint size)
 	}
 		
 	g_snprintf(user_agent, size,
-		   "Mozilla/5.0 %s/" VERSION " (X11; %s; U;) Gecko/%d",
-		   PACKAGE,
+		   "Mozilla/5.0 (X11; %s; U;) Gecko/%d Kazehakase/"  VERSION,
 		   system,
 		   NS_BUILD_ID/100);
 	g_free (system);
@@ -89,36 +89,23 @@ mozilla_prefs_set (void)
 {
 	char *value;
 	gchar user_agent[1024];
-	gboolean success, typeahead = FALSE;
+	gboolean override = FALSE, typeahead = FALSE;
+	gchar proxy_name[1024];
+	gboolean conf_exist = FALSE;
 
 	// set user agent name
-	success = kz_profile_get_value(kz_global_profile,
-				       "Global", "user_agent",
-				       &user_agent, sizeof(user_agent),
-				       KZ_PROFILE_VALUE_TYPE_STRING);
-	if (!success)
-		set_user_agent(user_agent, G_N_ELEMENTS(user_agent));
-	mozilla_prefs_set_string ("general.useragent.override",
-				  user_agent);
+	KZ_CONF_GET("Global", "override_user_agent", override, BOOL);
+	if (override)
+		override = KZ_CONF_GET("Global", "user_agent",
+				       user_agent, STRING);
+	if (!override)
+		build_user_agent(user_agent, G_N_ELEMENTS(user_agent));
+	mozilla_prefs_set_string ("general.useragent.override", user_agent);
 
 	// set typeahead or not
-	kz_profile_get_value(kz_global_profile,
-			     "Mozilla", "typeahead",
-			     &typeahead, sizeof(typeahead),
-			     KZ_PROFILE_VALUE_TYPE_BOOL);
+	KZ_CONF_GET("Mozilla", "typeahead", typeahead, BOOL);
 	mozilla_prefs_set_boolean ("accessibility.typeaheadfind",
 				   typeahead);	
-	if (!mozilla_prefs_get_string("kazehakase.startup.homepage", &value))
-	{
-		// start page
-		mozilla_prefs_set_string ("kazehakase.startup.homepage",
-					  "about:blank");
-	}
-	else
-	{
-		g_free(value);
-	}
-
 	if (!mozilla_prefs_get_string("kazehakase.font.language", &value))
 	{
 		mozilla_prefs_set_string("kazehakase.font.language",
@@ -128,6 +115,14 @@ mozilla_prefs_set (void)
 	{
 		g_free(value);
 	}
+
+	conf_exist = KZ_CONF_GET("Global", "proxy_name", proxy_name, STRING);
+	if (conf_exist)
+	{
+		KzProxyItem *item = kz_proxy_find(proxy_name);
+		mozilla_prefs_set_proxy(item);
+		g_object_unref(G_OBJECT(item));
+	}
 }
 
 
@@ -343,3 +338,61 @@ mozilla_prefs_get_font_list (const char *lang_group,
 
 	return TRUE;
 }
+
+
+extern "C" void
+mozilla_prefs_set_proxy (KzProxyItem *item)
+{
+	gboolean use_proxy, use_same_proxy;
+	gchar *name, *http_host, *https_host, *ftp_host, *no_proxies_on;
+	guint http_port, https_port, ftp_port;
+
+	g_return_if_fail(KZ_IS_PROXY_ITEM(item));
+
+	g_object_get(G_OBJECT(item),
+		     "name", &name,
+		     "use_proxy", &use_proxy,
+		     "use_same_proxy", &use_same_proxy,
+		     "http_host", &http_host,
+		     "http_port", &http_port,
+		     "https_host", &https_host,
+		     "https_port", &https_port,
+		     "ftp_host", &ftp_host,
+		     "ftp_port", &ftp_port,
+		     "no_proxies_on", &no_proxies_on,
+		     NULL);
+
+	if (!use_proxy)
+	{
+		mozilla_prefs_set_int("network.proxy.type", 0);
+		return;
+	}
+
+	mozilla_prefs_set_int   ("network.proxy.type",          1);
+	mozilla_prefs_set_string("network.proxy.http",          http_host);
+	mozilla_prefs_set_int   ("network.proxy.http_port",     http_port);
+	mozilla_prefs_set_string("network.proxy.no_proxies_on", no_proxies_on);
+
+	if (use_same_proxy)
+	{
+		https_host = ftp_host = http_host;
+		http_port = ftp_port = http_port;
+	}
+	else
+	{
+		if (!https_host)
+		{
+			https_host = "";
+			https_port = 0;
+		}
+		if (!ftp_host)
+		{
+			ftp_host = "";
+			ftp_port = 0;
+		}
+	}
+	mozilla_prefs_set_string("network.proxy.https",      https_host);
+	mozilla_prefs_set_int   ("network.proxy.https_port", https_port);
+	mozilla_prefs_set_string("network.proxy.ftp",        ftp_host);
+	mozilla_prefs_set_int   ("network.proxy.ftp_port",   ftp_port);
+}
